==> ejc-other-api-3.0.0-20230526.050653-99-sources.jar: com/ejianc/business/other/history/SettleHistoryVo.java <==
package com.ejianc.business.other.history;

import com.ejianc.business.other.vo.OtherSettleVO;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class SettleHistoryVo extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;
    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;
    /**
     * 类及结算金额
     */
    private BigDecimal sumSettleTaxMny;
    //累计比例
    private BigDecimal sumSettleRate;
    private Integer isFinish;
    private List<OtherSettleVO> settleRecord = new ArrayList<>();

    public Integer getIsFinish() {
        return isFinish;
    }

    public void setIsFinish(Integer isFinish) {
        this.isFinish = isFinish;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getSumSettleTaxMny() {
        return sumSettleTaxMny;
    }

    public void setSumSettleTaxMny(BigDecimal sumSettleTaxMny) {
        this.sumSettleTaxMny = sumSettleTaxMny;
    }

    public BigDecimal getSumSettleRate() {
        return sumSettleRate;
    }

    public void setSumSettleRate(BigDecimal sumSettleRate) {
        this.sumSettleRate = sumSettleRate;
    }

    public List<OtherSettleVO> getSettleRecord() {
        return settleRecord;
    }

    public void setSettleRecord(List<OtherSettleVO> settleRecord) {
        this.settleRecord = settleRecord;
    }
}

==> ejc-other-api-3.0.0-20250912.060157-159-sources.jar: com/ejianc/business/other/history/SettleHistoryVo.java <==
package com.ejianc.business.other.history;

import com.ejianc.business.other.vo.OtherSettleVO;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class SettleHistoryVo extends BaseVO {
    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;
    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;
    /**
     * 类及结算金额
     */
    private BigDecimal sumSettleTaxMny;
    //累计比例
    private BigDecimal sumSettleRate;
    private Integer isFinish;
    private List<OtherSettleVO> settleRecord = new ArrayList<>();
    private String contractStatus; // 合同状态：1-未签订, 2-履约中，3-已封帐

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public Integer getIsFinish() {
        return isFinish;
    }

    public void setIsFinish(Integer isFinish) {
        this.isFinish = isFinish;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getSumSettleTaxMny() {
        return sumSettleTaxMny;
    }

    public void setSumSettleTaxMny(BigDecimal sumSettleTaxMny) {
        this.sumSettleTaxMny = sumSettleTaxMny;
    }

    public BigDecimal getSumSettleRate() {
        return sumSettleRate;
    }

    public void setSumSettleRate(BigDecimal sumSettleRate) {
        this.sumSettleRate = sumSettleRate;
    }

    public List<OtherSettleVO> getSettleRecord() {
        return settleRecord;
    }

    public void setSettleRecord(List<OtherSettleVO> settleRecord) {
        this.settleRecord = settleRecord;
    }
}
